<?php

namespace Bixo\Team\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Bixo\Team\Http\Resources\TeamResource;
use Bixo\Team\Http\Resources\TeamsCollection;
use Bixo\Team\Scopes\UserPublicScope;
use Bixo\Team\Models\User;

class UserPublicController extends BaseController
{

    /**
     * Show user's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = User::pushScope(new RequestScope())
            ->pushScope(new UserPublicScope())
            ->paginate($pageLimit)
            ->withQueryString();

        $users = new UsersCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('team::user.names'))
            ->view('team::public.user.index')
            ->data(compact('users', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show user.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = User::findBySlug($slug);
        $data = new UserResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('team::user.name'))
            ->view('team::public.user.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
